==> weld-integration-3.0-b74b-sources.jar: org/glassfish/weld/services/ServletServicesImpl.java <==
/*
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.
 *
 * Copyright 2009 Sun Microsystems, Inc. All rights reserved.
 *
 * The contents of this file are subject to the terms of either the GNU
 * General Public License Version 2 only ("GPL") or the Common Development
 * and Distribution License("CDDL") (collectively, the "License").  You
 * may not use this file except in compliance with the License. You can obtain
 * a copy of the License at https://glassfish.dev.java.net/public/CDDL+GPL.html
 * or glassfish/bootstrap/legal/LICENSE.txt.  See the License for the specific
 * language governing permissions and limitations under the License.
 *
 * When distributing the software, include this License Header Notice in each
 * file and include the License file at glassfish/bootstrap/legal/LICENSE.txt.
 * Sun designates this particular file as subject to the "Classpath" exception
 * as provided by Sun in the GPL Version 2 section of the License file that
 * accompanied this code.  If applicable, add the following below the License
 * Header, with the fields enclosed by brackets [] replaced by your own
 * identifying information: "Portions Copyrighted [year]
 * [name of copyright owner]"
 *
 * Contributor(s):
 *
 * If you wish your version of this file to be governed by only the CDDL or
 * only the GPL Version 2, indicate your decision by adding "[Contributor]
 * elects to include this software in this distribution under the [CDDL or GPL
 * Version 2] license."  If you don't indicate a single choice of license, a
 * recipient has the option to distribute your version of this file under
 * either the CDDL, the GPL Version 2 or to extend the choice of license to
 * its licensees as provided above.  However, if you add GPL Version 2 code
 * and therefore, elected the GPL Version 2 license, then the option applies
 * only if the new code is made subject to such option by the copyright
 * holder.
 */

package org.glassfish.weld.services;

import javax.servlet.ServletContext;

import org.glassfish.api.deployment.DeploymentContext;
import org.glassfish.weld.DeploymentImpl;
import org.glassfish.weld.WeldDeployer;

import org.jboss.weld.bootstrap.spi.BeanDeploymentArchive;
import org.jboss.weld.servlet.api.ServletServices;

public class ServletServicesImpl implements ServletServices {

    private DeploymentContext deploymentContext = null;

    public ServletServicesImpl(DeploymentContext deploymentContext) {
        this.deploymentContext = deploymentContext;
    }

    public BeanDeploymentArchive getBeanDeploymentArchive(ServletContext ctx) {
        DeploymentImpl deploymentImpl = (DeploymentImpl)deploymentContext.getTransientAppMetaData(
                WeldDeployer.WELD_DEPLOYMENT, DeploymentImpl.class);
        return deploymentImpl.getBeanDeploymentArchives().get(0);
    }

    public void cleanup() {

    }
}

==> weld-integration-3.1-b15-sources.jar: org/glassfish/weld/services/ServletServicesImpl.java <==
/*
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.
 *
 * Copyright 2009 Sun Microsystems, Inc. All rights reserved.
 *
 * The contents of this file are subject to the terms of either the GNU
 * General Public License Version 2 only ("GPL") or the Common Development
 * and Distribution License("CDDL") (collectively, the "License").  You
 * may not use this file except in compliance with the License. You can obtain
 * a copy of the License at https://glassfish.dev.java.net/public/CDDL+GPL.html
 * or glassfish/bootstrap/legal/LICENSE.txt.  See the License for the specific
 * language governing permissions and limitations under the License.
 *
 * When distributing the software, include this License Header Notice in each
 * file and include the License file at glassfish/bootstrap/legal/LICENSE.txt.
 * Sun designates this particular file as subject to the "Classpath" exception
 * as provided by Sun in the GPL Version 2 section of the License file that
 * accompanied this code.  If applicable, add the following below the License
 * Header, with the fields enclosed by brackets [] replaced by your own
 * identifying information: "Portions Copyrighted [year]
 * [name of copyright owner]"
 *
 * Contributor(s):
 *
 * If you wish your version of this file to be governed by only the CDDL or
 * only the GPL Version 2, indicate your decision by adding "[Contributor]
 * elects to include this software in this distribution under the [CDDL or GPL
 * Version 2] license."  If you don't indicate a single choice of license, a
 * recipient has the option to distribute your version of this file under
 * either the CDDL, the GPL Version 2 or to extend the choice of license to
 * its licensees as provided above.  However, if you add GPL Version 2 code
 * and therefore, elected the GPL Version 2 license, then the option applies
 * only if the new code is made subject to such option by the copyright
 * holder.
 */

package org.glassfish.weld.services;

import java.util.List;

import javax.servlet.ServletContext;

import org.glassfish.api.deployment.DeploymentContext;
import org.glassfish.weld.DeploymentImpl;
import org.glassfish.weld.WeldDeployer;

import org.jboss.weld.bootstrap.spi.BeanDeploymentArchive;
import org.jboss.weld.servlet.api.ServletServices;

public class ServletServicesImpl implements ServletServices {

    private DeploymentContext deploymentContext = null;

    public ServletServicesImpl(DeploymentContext deploymentContext) {
        this.deploymentContext = deploymentContext;
    }

    public BeanDeploymentArchive getBeanDeploymentArchive(ServletContext ctx) {
        BeanDeploymentArchive returnBDA = null;
        DeploymentImpl deploymentImpl = (DeploymentImpl)deploymentContext.getTransientAppMetaData(
                WeldDeployer.WELD_DEPLOYMENT, DeploymentImpl.class);
        List<BeanDeploymentArchive> bdaList = deploymentImpl.getBeanDeploymentArchives();
        for(BeanDeploymentArchive bda : bdaList) {
            if (((org.glassfish.weld.BeanDeploymentArchiveImpl)bda).getBDAType().equals(
                org.glassfish.weld.BeanDeploymentArchiveImpl.WAR)) {
                returnBDA = bda;
                break;
            }
        }
        return returnBDA;
    }

    public void cleanup() {

    }
}
